# Auth SDK

This document describes how to integrate with Auth SDK and use auth test App to start TomTom GO Fleet.

## CHANGE LOG

Version 2: 
Add Api getVersion()

## Integration guide

### Import library

The library is built as a standard AAR(Android Archive) file.
To use this library in your app module, proceed as follows:

1. Add the library to your project.
2. Modify the build.gradle to include the library.

Gradle:

```
allprojects {
    repositories {
        flatDir {
            dirs 'libs'
        }
    }
}
```

```
dependencies {
    compile(name:'TomTomGOFleet_AuthSDK', ext:'aar')
}
```
### Register Intent action
#### Intent for launching partner app 
**action name: com.tomtom.authentication.action.PARTNER_APP**

End user can launch the partner app via TomTom GO Fleet. To achieve this TomTom GO Fleet requires the partner app to listen to the Intent for starting the Activity.
Refer [PackageManager#queryIntentActivities()](https://developer.android.com/reference/android/content/pm/PackageManager#queryIntentActivities(android.content.Intent,%20int)) for the details.

It is mandatory to register the intent action in your "activity" as shown below.
Otherwise, TomTom GO Fleet does't know if the Partner App is installed from the user.

#### Intent for requesting token
**action name: com.tomtom.authentication.action.REQUEST_TOKEN**

TomTom GO Fleet app will request a token from partner app during startup, by sending a broadcast intent, partner app should respond to this intent by one of the following methods.
1. Send a token to TomTom GO Fleet app by calling `setToken(String token)`
2. Notify TomTom GO Fleet app that user attention is needed by calling "requesetUserLogin()", TomTom GO Fleet app will launch partner app using the intent for launching partner app

#### Sample AndroidManifest.xml

```xml
<manifest>
    <application
        ...
        >
        <activity android:name=".MainActivity">
            <intent-filter>
                <action android:name="com.tomtom.authentication.action.PARTNER_APP"/>
                <category android:name="android.intent.category.DEFAULT" />
            </intent-filter>
        </activity>
        <receiver android:name=".TokenBroadcastReceiver" android:exported="false">
            <intent-filter>
                <action android:name="com.tomtom.authentication.action.REQUEST_TOKEN"/>
                <category android:name="android.intent.category.DEFAULT" />
            </intent-filter>
        </receiver>
    </application>
</manifest>
```
## How to use test App

TomTom GO Fleet Auth SDK Test App is used to simulate the behavior of Partner app and demonstrate the used of the TomTom GO Fleet Auth SDK.

1. Install the Auth SDK Test App
```
    adb install path_to_apk
```
2. Connect to TomTom GO Fleet

   Launch Auth SDK Test App and click the "Connection" tab, and then click the "Connect" button to connect to TomTom GO Fleet.

   "Conn. status" on the left/top status panel will show "Connected" if connect successfully, otherwise show "Disconnected".

   Once connection is established, "Connect" button will become "Disconnect" button which is used to disconnect with TomTom GO Fleet.
>   **NOTE**: When the activity of AuthSDK Test is destroyed, the connection is lost automatically.
3. Get AuthenticationManager

   Click the "Connection" tab, and then click the "Get auth. manager" button.

   "Auth. manager" on the left/top status panel will show "Retrieve" if get auth. manager successfully, otherwise show "Not retreived".

>   **NOTE**: The AuthenticationManager will return null if the Connect Status is not CONNECTED.
4. Monitor status of authentication

   Click the "Connection" tab, and then click the "Add auth. listener" button.

   "Auth. listener" on the left/top status panel will show "Subscribed" if add listener successfully, otherwise show "Not subscribed".

   "Auth. status" on the left/top status panel will show current status of authentication.

   Once Auth. listener is subscribed, "Add auth. listener" will become "Remove auth. listener" which is used to remove the registered listener if you don't want to monitor the status of authentication.
5. Simulate the **VALID** token.
>   **IMPORTANT**: ACS integration is completed in ECR 3.1, please refer to the following instruction based on the version used.

*  Version >= ECR 3.1
   
   Click the "Token" tab, and then click the "Send token" button.

   To update the default valid token, Click on "Settings" tab, and then enter the token generated by the signing server or inside the release package, and then click the "Save token" button.
   >   **NOTE**: This token will be used by "Send token" button and simulating the action after recieve the intent for requesting token.

   To avoid entering the wrong content, it is recommended to use the adb command to enter the token
```
   adb shell input text "<the content of the token>"
```
*  Version < ECR 3.1
   
   Enter "valid" (not including ") and press "SEND TOKEN".
   
   If you want to simulate the invalid token, you can input any other text without containing "valid".
6. Launch TomTom GO Fleet

7. Simulate update partner information

   Click the "Partner info." tab, then input "Name", "Phone", "Email" and "Website", and then click the "Update partner info." button.

8. Simulate update configuration

   Click the "Configuration" tab, then click "End date" twice and calander should show up. After choosing the date, click the "OK" button, and then click "Update configuration" button.

9. Simulate the action when recieving **com.tomtom.authentication.action.REQUEST_TOKEN**

   Click the "Settings" tab, and then click the "Send Invalid Token" switch button. "On" means sending Invalid token, "Off" means sending valid token when recieving **com.tomtom.authentication.action.REQUEST_TOKEN**.

10. Simulate "Request use login"

    Click the "Connection" tab, and then click the "Request use login" button.
    
## Documentation

*  [API KDoc:](docs/index.html) Documentation for the current release
*  [Current Limitation:](LIMITATION.md) Limitation for the current release

## License
```
/*
 * Copyright (c) 2020 - 2021 TomTom N.V. All rights reserved.
 *
 * This software is the proprietary copyright of TomTom N.V. and its subsidiaries and may be
 * used for internal evaluation purposes or commercial use strictly subject to separate
 * licensee agreement between you and TomTom. If you are the licensee, you are only permitted
 * to use this Software in accordance with the terms of your license agreement. If you are
 * not the licensee then you are not authorised to use this software in any manner and should
 * immediately return it to TomTom N.V.
 */
 ```
